==> huaweicloudsdkiotanalytics-3.0.79-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/show_asset_new_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAssetNewRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'asset_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'asset_id': 'asset_id',
        'type': 'type'
    }

    def __init__(self, asset_id=None, type=None):
        """ShowAssetNewRequest - a model defined in huaweicloud sdk"""
        
        

        self._asset_id = None
        self._type = None
        self.discriminator = None

        self.asset_id = asset_id
        self.type = type

    @property
    def asset_id(self):
        """Gets the asset_id of this ShowAssetNewRequest.

        资产ID

        :return: The asset_id of this ShowAssetNewRequest.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this ShowAssetNewRequest.

        资产ID

        :param asset_id: The asset_id of this ShowAssetNewRequest.
        :type: str
        """
        self._asset_id = asset_id

    @property
    def type(self):
        """Gets the type of this ShowAssetNewRequest.

        SKETCH：草稿态；RELEASE：发布态

        :return: The type of this ShowAssetNewRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowAssetNewRequest.

        SKETCH：草稿态；RELEASE：发布态

        :param type: The type of this ShowAssetNewRequest.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAssetNewRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotanalytics-3.1.7-py2.py3-none-any.whl: huaweicloudsdkiotanalytics/v1/model/show_asset_new_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowAssetNewRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'asset_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'asset_id': 'asset_id',
        'type': 'type'
    }

    def __init__(self, asset_id=None, type=None):
        """ShowAssetNewRequest

        The model defined in huaweicloud sdk

        :param asset_id: 资产ID
        :type asset_id: str
        :param type: SKETCH：草稿态；RELEASE：发布态
        :type type: str
        """
        
        

        self._asset_id = None
        self._type = None
        self.discriminator = None

        self.asset_id = asset_id
        self.type = type

    @property
    def asset_id(self):
        """Gets the asset_id of this ShowAssetNewRequest.

        资产ID

        :return: The asset_id of this ShowAssetNewRequest.
        :rtype: str
        """
        return self._asset_id

    @asset_id.setter
    def asset_id(self, asset_id):
        """Sets the asset_id of this ShowAssetNewRequest.

        资产ID

        :param asset_id: The asset_id of this ShowAssetNewRequest.
        :type asset_id: str
        """
        self._asset_id = asset_id

    @property
    def type(self):
        """Gets the type of this ShowAssetNewRequest.

        SKETCH：草稿态；RELEASE：发布态

        :return: The type of this ShowAssetNewRequest.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ShowAssetNewRequest.

        SKETCH：草稿态；RELEASE：发布态

        :param type: The type of this ShowAssetNewRequest.
        :type type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowAssetNewRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
